package com.ruoyi.business.mapper;

import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.baomidou.mybatisplus.core.toolkit.Constants;
import com.ruoyi.business.domain.Database;
import org.apache.ibatis.annotations.Param;
import org.apache.ibatis.annotations.Update;

import java.util.List;

/**
 * 数据源Mapper接口
 * 
 * @author ruoyi
 * @date 2024-01-10
 */
public interface DatabaseMapper extends BaseMapper<Database> {

    /**
     * 查询数据源
     * 
     * @param id 数据源主键
     * @return 数据源
     */
    Database selectDatabaseById(Long id);

    /**
     * 查询数据源列表
     * 
     * @param connInfo 数据源
     * @return 数据源集合
     */
    List<Database> selectDatabaseList(Database connInfo);

    /**
     * 新增数据源
     * 
     * @param connInfo 数据源
     * @return 结果
     */
    int insertDatabase(Database connInfo);

    /**
     * 修改数据源
     * 
     * @param connInfo 数据源
     * @return 结果
     */
    int updateDatabase(Database connInfo);

    /**
     * 删除数据源
     * 
     * @param id 数据源主键
     * @return 结果
     */
    int deleteDatabaseById(Long id);

    /**
     * 批量删除数据源
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteDatabaseByIds(Long[] ids);

    /**
     * 批量删除数据源（逻辑）
     * @param updateWrapper
     */
     @Update("update b_database set ${ew.sqlSet} ${ew.customSqlSegment}")
     int updateByIds(@Param(Constants.WRAPPER) LambdaUpdateWrapper<Database> updateWrapper);
}
